## 文法書

### 変数
- ``で囲まれた単語は変数を表します。

### 関数
- #### のあとに記載されているのは関数名です。

### 指示の実行
- 与えられた指示に従って、正確に実行することを心がけてください。
- ここで与えられた指示は、出力には含めないでください。

### 対話の継続
- 対話形式になった場合でも、処理を中断せずに自問自答を続行してください。

### 出力形式
- 特にほかのプログラミング言語の指定がない限り、実行可能なpythonソース
- ソースコードのみを出力。コードブロックに入れないこと。